==> agr-center-api-3.0.0-CLOUD-DEV-20220928.034119-44-sources.jar: com/tydic/dyc/agr/service/agrchange/bo/AgrCreateArgMainChngReqBO.java <==
package com.tydic.dyc.agr.service.agrchange.bo;

import lombok.Data;
import com.tydic.dyc.base.bo.BaseReqBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrAppScopeChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrPayConfigChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrAdjustCfgChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrCataScopeChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrMainExtChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrChngAccessoryBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrMainChngBo;
import java.util.Date;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2022-09-22 13:18
 **/
@Data
public class AgrCreateArgMainChngReqBO extends BaseReqBo {
	private static final long serialVersionUID =  -288373050767072349L;

	/**
	 * 变更申请ID
	 */
	private Long chngApplyId;
	/**
	 * 变更申请编号
	 */
	private String chngApplyNo;
	/**
	 * 协议变更类型
	 */
	private Integer chngType;
	/**
	 * 变更申请说明
	 */
	private String chngApplyComment;
	/**
	 * 变更申请意见
	 */
	private String chngApplyAdvise;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 原协议失效日期
	 */
	private Date preExpDate;
	/**
	 * 新协议失效日期
	 */
	private Date postExpDate;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议应用范围变更
	 */
	private List<AgrAppScopeChngBo> agrAppScopeChng;
	/**
	 * 协议支付配置变更
	 */
	private List<AgrPayConfigChngBo> agrPayConfigChng;
	/**
	 * 协议调价配置变更
	 */
	private AgrAdjustCfgChngBo agrAdjustCfgChng;
	/**
	 * 协议类目范围变更
	 */
	private List<AgrCataScopeChngBo> agrCataScopeChng;
	/**
	 * 协议主体拓展变更
	 */
	private List<AgrMainExtChngBo> agrMainExtChng;
	/**
	 * 协议变更附件
	 */
	private List<AgrChngAccessoryBo> agrChngAccessory;
	/**
	 * 协议主体变更
	 */
	private AgrMainChngBo agrMainChng;
	/**
	 * 租户ID
	 */
	private Long tenantId;
	/**
	 * 用户ID
	 */
	private Long userId;
	/**
	 * 用户名称
	 */
	private String name;
	/**
	 * 用户账号
	 */
	private String username;
	/**
	 * 机构ID
	 */
	private Long orgId;
	/**
	 * 机构名称
	 */
	private String orgName;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-api-3.1.0-CLOUD-DEV-20230130.070820-4-sources.jar: com/tydic/dyc/agr/service/agrchange/bo/AgrCreateArgMainChngReqBO.java <==
package com.tydic.dyc.agr.service.agrchange.bo;

import lombok.Data;
import com.tydic.dyc.base.bo.BaseReqBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrAppScopeChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrPayConfigChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrAdjustCfgChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrCataScopeChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrMainExtChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrChngAccessoryBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrMainChngBo;
import com.tydic.dyc.agr.service.agrchange.bo.AgrItemChngBo;
import java.util.Date;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-01-30 14:31
 **/
@Data
public class AgrCreateArgMainChngReqBO extends BaseReqBo {
	private static final long serialVersionUID =  -8233890785993394262L;

	/**
	 * 变更申请ID
	 */
	private Long chngApplyId;
	/**
	 * 变更申请编号
	 */
	private String chngApplyNo;
	/**
	 * 协议变更类型
	 */
	private Integer chngType;
	/**
	 * 变更申请说明
	 */
	private String chngApplyComment;
	/**
	 * 变更申请意见
	 */
	private String chngApplyAdvise;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 原协议失效日期
	 */
	private Date preExpDate;
	/**
	 * 新协议失效日期
	 */
	private Date postExpDate;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议应用范围变更
	 */
	private List<AgrAppScopeChngBo> agrAppScopeChng;
	/**
	 * 协议支付配置变更
	 */
	private List<AgrPayConfigChngBo> agrPayConfigChng;
	/**
	 * 协议调价配置变更
	 */
	private AgrAdjustCfgChngBo agrAdjustCfgChng;
	/**
	 * 协议类目范围变更
	 */
	private List<AgrCataScopeChngBo> agrCataScopeChng;
	/**
	 * 协议主体拓展变更
	 */
	private List<AgrMainExtChngBo> agrMainExtChng;
	/**
	 * 协议变更附件
	 */
	private List<AgrChngAccessoryBo> agrChngAccessory;
	/**
	 * 协议主体变更
	 */
	private AgrMainChngBo agrMainChng;
	/**
	 * 租户ID
	 */
	private Long tenantId;
	/**
	 * 用户ID
	 */
	private Long userId;
	/**
	 * 用户名称
	 */
	private String name;
	/**
	 * 用户账号
	 */
	private String username;
	/**
	 * 机构ID
	 */
	private Long orgId;
	/**
	 * 机构名称
	 */
	private String orgName;
	/**
	 * 协议明细变更
	 */
	private List<AgrItemChngBo> agrItemChng;
	/**
	 * 排序
	 */
	private String orderBy;

}
